import { BasicColumn, FormSchema } from '@/components/Table';

/**源端配置-left-表单 */
export const sourceSideConfigurationFormSchema: FormSchema[] = [
  {
    field: 'logParser',
    label: '日志解析器',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        loadType.value = formModel.loadType;
      },
      options: [
        { label: 'Canal', value: '1' },
        { label: 'OGG', value: '2' },
      ],
    }),
  },
  {
    field: 'metadataAcquisitionMode',
    label: '元数据获取方式',
    component: 'RadioGroup',
    defaultValue: '从JDBC获取元数据',
    show: ({ model }) => {
      return model.logParser === '2';
    },
    // show: false,
    componentProps: ({ formModel, formActionType }) => ({
      options: [
        { label: '从JDBC获取元数据', value: '从JDBC获取元数据' },
        // { label: '自定义SQL', value: '自定义SQL' },
        { label: '导入元数据文件', value: '导入元数据文件' },
      ],
    }),
  },
  {
    field: 'dataSource',
    label: '数据源',
    component: 'Select',
    required: true,
    defaultValue: [],
    componentProps: {
      placeholder: '请选择数据源',
      options: [
        { label: 'KunDB数据源', value: 'KunDB数据源' },
        { label: 'MongoDB数据源', value: 'MongoDB数据源' },
        { label: 'AmazonS3', value: 'AmazonS3' },
      ],
    },
  },
  {
    field: 'dataBase',
    label: '数据库',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '请选择数据',
      displayRender: ({ labels }) => {
        return labels[labels.length - 1];
      },
      options: [
        {
          value: 'ArgoDB_Dev01',
          label: 'ArgoDB_Dev01',
        },
        {
          value: 'ArgoDB_Dev02',
          label: 'ArgoDB_Dev02',
        },
        {
          value: 'GbaseDB_Dev01',
          label: 'GbaseDB_Dev01',
        },
      ],
    },
  },

  {
    field: 'getMetadata',
    label: ' ',
    component: 'Slot',
    slot: 'getMetadata',
  },
];

/**源端配置-获取元数据按钮(弹窗)-字段名 */
export const getMetadataColumns: BasicColumn[] = [
  {
    title: '表名',
    dataIndex: 'tableName',
  },
];
/**源端配置-right-表单 */
export const LoadingStrategyFormSchema: FormSchema[] = [
  {
    field: 'primaryKeyColumn',
    label: '主键列',
    component: 'Select',
    colProps: { lg: 23, md: 23 },
    componentProps: {
      mode: 'multiple',
    },
    ifShow: false,
    required: true,
  },
  {
    field: 'notCustomSQLTable',
    component: 'Slot',
    slot: 'notCustomSQLTable',
    // ifShow: false,
  },
];

/**源端配置-右-列表字段配置 */
export const notCustomSQLColumns: BasicColumn[] = [
  {
    title: '列名',

    dataIndex: 'fieldName',
  },
  {
    title: '类型',
    dataIndex: 'fieldType',
  },
];

/**映射规则配置-新增规则按钮-新增字段规则表单*/
export const NewFieldRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldRuleAlert',
    slot: 'newFieldRuleAlert',
  },
  {
    field: 'newFieldName',
    label: '新增字段名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldType',
    label: '新增字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'STRING', value: 'STRING' },
        { label: 'INTEGER', value: 'INTEGER' },
        { label: 'FLOAT', value: 'FLOAT' },
        { label: 'DECIMAL', value: 'DECIMAL' },
        { label: 'DATE', value: 'DATE' },
        { label: 'TIMESTAMP', value: 'TIMESTAMP' },
        { label: 'BOOLEAN', value: 'BOOLEAN' },
      ]
    },
    required: true,
  },
  {
    field: 'fieldExpression',
    label: '字段表达式',
    component: 'Input',
    required: true,
  },
];
/**映射规则配置-新增规则按钮-字段名映射规则表单*/
export const FieldNameMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'regularExpressionAlert',
    slot: 'regularExpressionAlert',
  },
  {
    field: 'regularExpression',
    label: '正则表达式',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.regularExpression;
        formActionType.updateSchema([{ field: 'sourceDatabaseNameExpression', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'targetLibraryNameExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'sourceDatabaseNameExpression',
    label: '源库名表达式',
    component: 'Input',
    defaultValue: '^(.*)$',
    required: true,
    ifShow: false,
  },
  {
    field: 'targetLibraryNameExpression',
    label: '目标库名表达式',
    defaultValue: 'test_$1_obs',
    component: 'Input',
    ifShow: false,
  },
  {
    field: 'addPrefix',
    label: '添加前缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addPrefix;
        formActionType.updateSchema([{ field: 'prefixExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'prefixExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: 'test_',
    required: true,
    ifShow: false,
  },
  {
    field: 'addSuffixation',
    label: '添加后缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addSuffixation;
        formActionType.updateSchema([{ field: 'suffixationExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'suffixationExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: '_obs',
    required: true,
    ifShow: false,
  },
  {
    field: 'reviewButton',
    label: '',
    slot: 'reviewButton',
  },
  {
    field: 'reviewTable',
    label: '',
    slot: 'reviewTable',
  },
];

/**映射规则配置-新增规则按钮-字段名称映射规则列-列表字段 */
export const fieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '源字段名',
    dataIndex: 'fieldName',
    labelWidth: 160,
  },
  {
    title: '目标字段名',
    dataIndex: 'targetFieldName',
  },
];

/**映射规则配置-新增规则按钮-字段类型映射规则表单*/
export const FieldTypeMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldRuleAlert',
    slot: 'newFieldRuleAlert',
  },
  {
    field: 'sourceFieldType',
    label: '源字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'STRING', value: 'STRING' },
        { label: 'INTEGER', value: 'INTEGER' },
        { label: 'FLOAT', value: 'FLOAT' },
        { label: 'DECIMAL', value: 'DECIMAL' },
        { label: 'DATE', value: 'DATE' },
        { label: 'TIMESTAMP', value: 'TIMESTAMP' },
        { label: 'BOOLEAN', value: 'BOOLEAN' },
      ]
    },
    required: true,
  },
  {
    field: 'targetFieldType',
    label: '目标字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'STRING', value: 'STRING' },
        { label: 'INTEGER', value: 'INTEGER' },
        { label: 'FLOAT', value: 'FLOAT' },
        { label: 'DECIMAL', value: 'DECIMAL' },
        { label: 'DATE', value: 'DATE' },
        { label: 'TIMESTAMP', value: 'TIMESTAMP' },
        { label: 'BOOLEAN', value: 'BOOLEAN' },
      ]
    },
    required: true,
  },
];

/**映射规则配置-新增规则按钮-单表字段映射规则表单*/
export const SingleTableFieldMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'selectiveDataTable',
    label: '选择数据表',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'table_1', value: 'table_1' },
        { label: 'table_2', value: 'table_2' },
        { label: 'table_3', value: 'table_3' },
        { label: 'table_4', value: 'table_4' },
      ],
    },
    required: true,
  },
  {
    field: 'mappingTable',
    slot: 'mappingTable',
  },
];

/**映射规则配置-新增规则按钮-单目标表字段映射规则列-列表字段 */
export const singleGoalFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'targetFieldName',
    edit: true,
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    edit: true,
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];

/**映射规则配置-新增规则按钮-单源表字段映射规则列-列表字段 */
export const singleSourceFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'fieldName',
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];

/**映射规则配置-数据转换规则-列表字段 */
export const mappingRuleConfigurationColumns: BasicColumn[] = [
  {
    title: '规则类型',
    dataIndex: 'ruleType',
    align: 'left',
    width: 220,
    slots: { customRender: 'ruleType' },
  },
  {
    title: '规则内容',
    dataIndex: 'ruleContent',
    align: 'left',
    slots: { customRender: 'ruleContent' },
  },
];
