import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';
import { InputProps } from 'ant-design-vue';

export const fileUploadSchema: FormSchema[] = [
  {
    label: '文件位置',
    field: 'type',
    defaultValue: '本地',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '本地',
          value: '本地',
        },
        {
          label: '文件系统',
          value: '文件系统',
        },
      ],
    },
  },
  {
    label: '文件存储地址',
    field: 'address',
    show: ({ model }) => {
      return model.type === '本地';
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '65_hdfs',
          value: '65_hdfs',
        },
      ],
    },
  },
  {
    label: '上传文件',
    field: 'file',
    show: ({ model }) => {
      return model.type === '本地';
    },
    slot: 'file',
  },
  {
    label: '选择加载方式',
    field: 'loadingType',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    defaultValue: '全量文件加载',
    slot: 'loadingType',
  },
  {
    label: '数据源',
    field: 'dataSource',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '088-hdfs',
          value: '088-hdfs',
        },
      ],
    },
  },
  {
    label: '路径',
    field: 'path',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    slot: 'path',
  },
  {
    label: '文件过滤(选填)',
    field: 'filter',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    component: 'Input',
    componentProps: {
      placeholder: '包含完整路径的文件名正则表达式，例如/hadoop/data_*',
    },
  },
  {
    label: '列分隔符',
    field: 'delimiter',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '列起止符',
    field: 'startStop',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '编码格式',
    field: 'encoding',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '导入sheet名称',
    field: 'sheet',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'sheet',
  },
  {
    label: '是否包含表头',
    field: 'head',
    defaultValue: '是',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
  },
  {
    label: '表头起止行数',
    field: 'header',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel' && model.head === '是';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel' && model.head === '是';
    },
    slot: 'header',
  },
  {
    label: '数据起止行数',
    field: 'row',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'row',
  },
  {
    label: '文件起止列数',
    field: 'column',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'column',
  },
];
export const fileTableColumn: BasicColumn[] = [
  {
    dataIndex: 'c1',
  },
  {
    dataIndex: 'c2',
  },
  {
    dataIndex: 'c3',
  },
  {
    dataIndex: 'c4',
  },
  {
    dataIndex: 'c5',
  },
  {
    dataIndex: 'c6',
  },
  {
    dataIndex: 'c7',
  },
  {
    dataIndex: 'c8',
  },
  {
    dataIndex: 'c9',
  },
  {
    dataIndex: 'c10',
  },
];
export const dataSourceUploadSchema: FormSchema[] = [
  {
    label: '数据源',
    field: 'dataSource',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '64_inceptor',
          value: '64_inceptor',
        },
      ],
    },
  },
  {
    label: '清空目标表',
    field: 'clear',
    defaultValue: '是',
    slot: 'clear',
  },
  {
    label: '目标库',
    field: 'database',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'gxx',
          value: 'gxx',
        },
      ],
    },
  },
  {
    label: '允许最大并发度',
    field: 'concurrent',
    component: 'Input',
  },
  {
    label: 'HDFS数据源',
    field: 'hdfsSource',
    required: true,
    helpMessage: 'HDFS数据源',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '65_hdfs',
          value: '65_hdfs',
        },
      ],
    },
  },
  {
    label: '目标表快照',
    field: 'snapshot',
    defaultValue: '否',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
  },
];
export const dataSourceFieldFormSchema: FormSchema[] = [
  {
    label: '是否自动建表',
    field: 'createTable',
    helpMessage: '是否自动建表',
    defaultValue: '否',
    slot: 'createTable',
  },
  {
    label: '目标表名',
    field: 'tableName',
    required: true,
    show: ({ model }) => {
      return model.createTable === '是';
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'Table1',
          value: 'Table1',
        },
        {
          label: 'Table2',
          value: 'Table2',
        },
      ],
    },
  },
];
export const dataSourceTableColumn: BasicColumn[] = [
  {
    title: '源端',
    dataIndex: 'source',
    slots: { customRender: 'source' },
    width: 200,
  },
  {
    title: '目标端',
    dataIndex: 'target',
    slots: { customRender: 'target' },
    width: 200,
  },
  {
    title: '分区数据配置',
    dataIndex: 'areaConfig',
    slots: { customRender: 'areaConfig' },
    width: 50,
  },
  {
    title: '清理配置',
    dataIndex: 'clearConfig',
    slots: { customRender: 'clearConfig' },
    width: 50,
  },
];
export const dataSourceFieldTableColumn: BasicColumn[] = [
  {
    title: '源字段',
    dataIndex: 'sourceField',
    slots: { customRender: 'sourceField' },
  },
  {
    title: '目标字段',
    dataIndex: 'targetField',
    slots: { customRender: 'targetField' },
  },
  {
    title: '字段注解',
    dataIndex: 'fieldRemark',
    slots: { customRender: 'fieldRemark' },
  },
];
export const dataSourceSqlFormSchema: FormSchema[] = [
  {
    label: '表类型',
    field: 'type',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'TEXT',
          value: 'TEXT',
        },
        {
          label: 'ORC',
          value: 'ORC',
        },
        {
          label: 'TORC',
          value: 'TORC',
        },
      ],
    },
  },
  {
    field: '',
    slot: 'title1',
  },
  {
    label: '分区',
    field: 'area',
    defaultValue: '无',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '无',
          value: '无',
        },
        {
          label: '单值分区',
          value: '单值分区',
        },
        {
          label: '范围分区',
          value: '范围分区',
        },
      ],
    },
  },
  {
    field: '',
    slot: 'title2',
  },
  {
    label: '分桶',
    field: 'bucket',
    defaultValue: '否',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '否',
          value: '否',
        },
        {
          label: '是',
          value: '是',
        },
      ],
    },
  },
  {
    field: '',
    slot: 'title3',
  },
  {
    field: 'otherConfigType',
    component: 'Select',
    defaultValue: '表注释',
    show: false,
  },
  {
    field: 'otherConfig',
    slot: 'otherConfig',
  },
];
export const showLogFormSchema: FormSchema[] = [
  {
    field: 'tableName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入表名',
    },
  },
];
export const showLogTable: BasicColumn[] = [
  {
    title: '源表名',
    dataIndex: 'sourceTable',
  },
  {
    title: '目标表名',
    dataIndex: 'targetTable',
  },
  {
    title: '表类型',
    width: 90,
    dataIndex: 'tableType',
  },
  {
    title: '分区类型',
    width: 90,
    dataIndex: 'areaType',
  },
  {
    title: '分区键',
    width: 100,
    dataIndex: 'partitionKey',
  },
  {
    title: '调试结果',
    dataIndex: 'debuggingResult',
  },
];
export const showTableFormSchema: FormSchema[] = [
  {
    field: 'columnName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入列名',
    },
  },
];
export const showTableColumn: BasicColumn[] = [
  {
    title: '源列名',
    dataIndex: 'sourceColumnName',
    slots: { customRender: 'sourceColumnName' },
  },
  {
    title: '目标列名',
    dataIndex: 'targetColumnName',
    slots: { customRender: 'targetColumnName' },
  },
];
export const dataFilterRuleModalFormSchema: FormSchema[] = [
  {
    label: '规则名称',
    field: 'name',
    required: true,
    component: 'Input',
  },
  {
    label: '自定义规则',
    field: 'rule',
    component: 'InputTextArea',
    componentProps: {
      placeholder: '请输入自定义过滤规则',
      rows: 4,
    } as InputProps,
  },
];
